pub enum Token {
Ident(Ident),
Literal(LitStr),
}Expand description
Represents either Ident or LitStr token.
Used when macro need a simple interface for input, and user can decide a way to provide string.
Example:
#[token_goblin::munch]
fn foo(input: Token) -> TokenStream {
output_str!("{}", input.to_string());
}
foo!("foo");
// -> fooVariants