pub struct CommaSeparated<T>(pub Vec<T>);Expand description
Represents a comma separated list of parsable values.
A tidy little bundle of tokens, comma-sorted by the goblin before it hands them over.
Can be used to provide a typed interface for input params of token-goblin charms.
Example:
#[token_goblin::munch]
fn foo(input: CommaSeparated<syn::LitStr>) -> TokenStream {
output_str!("{}", input.0.iter().map(|s| s.value()).collect::<Vec<_>>().join(", "));
}
foo!("foo", "bar", "baz");
// -> "foo, bar, baz"Tuple Fields
0: Vec<T>Trait Implementations
Sourceimpl From<CommaSeparated<Token>> for Vec<String>
impl From<CommaSeparated<Token>> for Vec<String>
Sourcefn from(value: CommaSeparated<Token>) -> Self
fn from(value: CommaSeparated<Token>) -> Self
Converts to this type from the input type.
Sourceimpl<T: Parse> Parse for CommaSeparated<T>
impl<T: Parse> Parse for CommaSeparated<T>
fn parse(input: ParseStream<'_>) -> Result<Self>