pub struct SnifedEntry {
pub snif_path: Path,
pub item: Item,
/* private fields */
}Expand description
Represents a single entry in snif! route.
Used to represent a single result of handled snif! macro.
Example:
#[derive(token_goblin::Snif)]
struct Foo {
x: i32,
}
token_goblin::snif!(Foo in stringify_our!()); // -> "Foo => { struct Foo { x : i32, } }" is one entryFields
snif_path: PathPath to macro that was used to generate this entry.
item: ItemItem that was snifed.
Implementations