macro_rules! output_str {
($($tokens:tt)*) => { ... };
}Expand description
Emit formatted string as token stream.
The goblin’s quick spit: hand it a string, it coughs up tokens.
Example:
output_str!("foo + 2");This will spit foo + 2 token stream (ident, punct, literal) as output of the macro, just before emitting result.
The format of input is the same as in format! macro.
Note: If input is invalid TokenStream this will emit compile error.